Samples new coefficients via Gibbs sampling in a spectral GP object
following the Gibbs sampling scheme of Wikle (2002), which involves an
extra variance component (sig2e and a noisy version of the
process (z).
# S3 method for gp
Gibbs.sample.coeff(object, z, sig2e, meanVal=0,
sdVal=1,returnHastings=FALSE, ...)The function modifies the GP object, which is essentially a pointer
(an R environment in this case), so NULL is returned, unless returnHastings=TRUE.
A GP object, created by gp.
Vector of values for z, the noisy version of the process.
Noise variance component that distorts z as a
version of the process.
Optional mean value for z.
Optional standard deviation value for z.
Optional argument telling whether to return the logdensity of the proposal for use in a Metropolis-Hastings correction calculation.
Other arguments.
Christopher Paciorek paciorek@alumni.cmu.edu
This function can be used in an MCMC context to take Gibbs samples
of the process coefficients, as part of the algorithm of Wikle
(2002). The function modifies the GP object, updating the coeff and
process components.
Type 'citation("spectralGP")' for references.
gp, propose.coeff.gp, updateprocess.gp