Calculates Hastings value of coefficients, the logdensity of the current
coefficients given proposal mean and variance based on a Gibbs sample
of the form in Gibbs.sample.coeff.gp.
# S3 method for gp
Hastings.coeff(object, z, sig2e, meanVal=0, sdVal=1, ...)The function returns the logdensity.
A GP object, created by gp.
Vector of values for z, the noisy version of the process.
Noise variance component that distorts z as a
version of the process.
Optional mean value for z.
Optional standard deviation value for z.
Other arguments.
Christopher Paciorek paciorek@alumni.cmu.edu
This function can be used in an MCMC context to calculate the Hastings correction that may be necessary in taking a quasi-Gibbs sample of the process coefficients, as part of one of the algorithms of Paciorek (2006). The function calculates and returns the logdensity.
Type 'citation("spectralGP")' for references.
gp, propose.coeff.gp, updateprocess.gp