print.gp: Spectral GP default print statement

View source: R/print.gp.R

print.gpR Documentation

Spectral GP default print statement

Description

This is the default print statement for a spectral GP object. If you need a list of everything that is part of a spectral GP object, use 'names()'.

Author(s)

Christopher Paciorek paciorek@alumni.cmu.edu

References

Type 'citation("spectralGP")' for references.

See Also

gp, names.gp


spectralGP documentation built on Feb. 6, 2026, 1:07 a.m.