Hastings.coeff.gp: Calculates Hastings value of coefficients
Description
Calculates Hastings value of coefficients, the logdensity of the current
coefficients given proposal mean and variance based on a Gibbs sample
of the form in Gibbs.sample.coeff.gp.Usage
## S3 method for class 'gp':
Hastings.coeff(object, z, sig2e, meanVal=0, sdVal=1, \dots)
Arguments
object
A GP object, created by gp.
z
Vector of values for z, the noisy version of the process.
sig2e
Noise variance component that distorts z as a
version of the process.
meanVal
Optional mean value for z.
sdVal
Optional standard deviation value for z.
Value
- The function returns the logdensity.
Details
This function can be used in an MCMC context to calculate the Hastings correction
that may be necessary in taking a quasi-Gibbs sample of the process
coefficients, as part of one of the algorithms of Paciorek (2006).
The function calculates and returns the logdensity.References
Type 'citation("spectralGP")' for references.